@@ -122,7 +122,7 @@ def addDebugArgs(opt: _ArgumentGroup) -> None:
 
 
 def addLogArgs(opt, prog):
-    """Logfile argument"""
+    """Logging related arguments"""
     opt.add_argument(
         "-L",
         "--logfile",
@@ -130,3 +130,13 @@ def addLogArgs(opt, prog):
         type=str,
         help="Path to Logfile (default: %(default)s)",
     )
+
+
+def addLogColorArgs(opt):
+    """Option to enable or disable colored output"""
+    opt.add_argument(
+        "--nocolor",
+        default=False,
+        help="Disable colored output (default: %(default)s)",
+        action="store_true",
+    )
