@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 """
-    Copyright (C) 2021  Michael Ablassmeier <abi@grinser.de>
+    Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 import logging
-from logging import LogRecord
 
 
 class logCount(logging.Handler):
@@ -33,7 +32,7 @@ class logCount(logging.Handler):
         super().__init__()
         self.count = self.LogType()
 
-    def emit(self, record: LogRecord) -> None:
+    def emit(self, record: logging.LogRecord) -> None:
         if record.levelname == "WARNING":
             self.count.warnings += 1
         if record.levelname in ("ERROR", "FATAL", "CRITICAL"):
