@@ -17,48 +17,12 @@
 import os
 import logging
 from time import sleep
-from dataclasses import dataclass
 import nbd
 from libvirtnbdbackup.nbdcli import exceptions
 
 log = logging.getLogger("nbd")
 
 
-@dataclass
-class nbdConn:
-    """NBD connection"""
-
-    exportName: str
-    metaContext: str
-
-
-@dataclass
-class Unix(nbdConn):
-    """NBD connection type unix for connection via socket file"""
-
-    backupSocket: str
-    tls: bool = False
-
-    def __post_init__(self):
-        self.uri = f"nbd+unix:///{self.exportName}?socket={self.backupSocket}"
-
-
-@dataclass
-class TCP(nbdConn):
-    """NBD connection type tcp for remote backup"""
-
-    hostname: str
-    tls: bool
-    port: int = 10809
-    backupSocket: str = ""
-    uri_prefix = "nbd://"
-
-    def __post_init__(self):
-        if self.tls:
-            self.uri_prefix = "nbds://"
-        self.uri = f"{self.uri_prefix}{self.hostname}:{self.port}/{self.exportName}"
-
-
 class client:
     """Helper functions for NBD"""
 
@@ -131,15 +95,19 @@ class client:
             if self.cType.backupSocket and not os.path.exists(self.cType.backupSocket):
                 log.info("Waiting for NBD Server, Retry: %s", retry)
                 retry = retry + 1
+                continue
 
-            connection = self._connect()
-            if connection:
-                log.info("Connection to NBD backend succeeded.")
-                self.connection = connection
-                return self
+            try:
+                connection = self._connect()
+            except exceptions.NbdConnectionError as e:
+                self.nbd = nbd.NBD()
+                log.info("Waiting for NBD Server, Retry: %s [%s]", retry, e)
+                retry = retry + 1
+                continue
 
-            log.info("Waiting for NBD Server, Retry: %s", retry)
-            retry = retry + 1
+            log.info("Connection to NBD backend succeeded.")
+            self.connection = connection
+            return self
 
     def disconnect(self) -> None:
         """Close nbd connection handle"""
