@@ -1,5 +1,5 @@
 """
-    Copyright (C) 2021  Michael Ablassmeier <abi@grinser.de>
+    Copyright (C) 2023  Michael Ablassmeier <abi@grinser.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,4 @@
 """
 
 __title__ = "qemu"
-__version__ = "0.1"
-
-from .util import util
-
-runcmd = util("").runcmd
+__version__ = "0.2"
