@@ -23,7 +23,7 @@ from typing import List
 from argparse import Namespace
 
 from libvirtnbdbackup.ssh.exceptions import sshError
-from libvirtnbdbackup.processinfo import processInfo
+from libvirtnbdbackup.objects import processInfo
 from libvirtnbdbackup.qemu import command
 from libvirtnbdbackup.virt.client import DomainDisk
 
@@ -144,6 +144,9 @@ class util:
         ]
         if args.tls is True:
             self._addTls(cmd, args.tls_cert)
+        if args.nbd_ip != "":
+            cmd.append("-b")
+            cmd.append(args.nbd_ip)
         cmd.append(f"> {logFile} 2>&1")
         try:
             return args.sshClient.run(" ".join(cmd), pidFile, logFile)
