@@ -18,13 +18,11 @@ import os
 import string
 import random
 import logging
-from dataclasses import dataclass
 from socket import gethostname
 from argparse import Namespace
 from typing import Any, Dict, List, Tuple, Union
-from lxml.etree import _Element
-from lxml import etree as ElementTree
 import libvirt
+from libvirtnbdbackup.objects import DomainDisk
 from libvirtnbdbackup.virt.exceptions import (
     domainNotFound,
     connectionFailed,
@@ -35,17 +33,6 @@ from libvirtnbdbackup.virt import xml
 from libvirtnbdbackup.virt import disktype
 
 
-@dataclass
-class DomainDisk:
-    """Domain disk object"""
-
-    target: str
-    format: str
-    filename: str
-    path: str
-    backingstores: list
-
-
 def libvirt_ignore(
     _ignore: None, _err: Tuple[int, int, str, int, str, str, None, int, int]
 ) -> None:
@@ -166,6 +153,11 @@ class client:
 
         return self._connectOpen(args.uri)
 
+    def close(self) -> None:
+        """Disconnect"""
+        log.debug("Close connection to libvirt.")
+        self._conn.close()
+
     def getDomain(self, name: str) -> libvirt.virDomain:
         """Lookup domain"""
         try:
@@ -273,85 +265,8 @@ class client:
         log.debug("Domain Info: [%s]", settings)
         return settings
 
-    def adjustDomainConfigRemoveDisk(self, vmConfig: str, excluded) -> bytes:
-        """Remove disk from config, in case it has been excluded
-        from the backup."""
-        tree = xml.asTree(vmConfig)
-        log.info("Removing excluded disk [%s] from vm config.", excluded)
-        try:
-            target = tree.xpath(f"devices/disk/target[@dev='{excluded}']")[0]
-            disk = target.getparent()
-            disk.getparent().remove(disk)
-        except IndexError:
-            log.warning("Removing excluded disk from config failed: no object found.")
-
-        return ElementTree.tostring(tree, encoding="utf8", method="xml")
-
-    def adjustDomainConfig(
-        self, args: Namespace, restoreDisk: DomainDisk, vmConfig: str, targetFile: str
-    ) -> bytes:
-        """Adjust virtual machine configuration after restoring. Changes
-        the paths to the virtual machine disks and attempts to remove
-        components excluded during restore."""
-        tree = xml.asTree(vmConfig)
-
-        try:
-            log.info("Removing uuid setting from vm config.")
-            uuid = tree.xpath("uuid")[0]
-            tree.remove(uuid)
-        except IndexError:
-            pass
-
-        name = tree.xpath("name")[0]
-        if args.name is None:
-            domainName = f"restore_{name.text}"
-        else:
-            domainName = args.name
-        log.info("Changing name from [%s] to [%s]", name.text, domainName)
-        name.text = domainName
-
-        for disk in tree.xpath("devices/disk"):
-            if disk.get("type") == "volume":
-                log.info("Disk has type volume, resetting to type file.")
-                disk.set("type", "file")
-
-            dev = disk.xpath("target")[0].get("dev")
-            log.debug("Handling target device: [%s]", dev)
-
-            device = disk.get("device")
-            driver = disk.xpath("driver")[0].get("type")
-
-            if disktype.Optical(device, dev):
-                log.info("Removing device [%s], type [%s] from vm config", dev, device)
-                disk.getparent().remove(disk)
-                continue
-
-            if disktype.Raw(driver, device):
-                log.warning(
-                    "Removing raw disk [%s] from vm config, use --raw to copy as is.",
-                    dev,
-                )
-                disk.getparent().remove(disk)
-                continue
-            backingStore = disk.xpath("backingStore")
-            if backingStore:
-                log.info("Removing existent backing store settings")
-                disk.remove(backingStore[0])
-
-            originalFile = disk.xpath("source")[0].get("file")
-            if dev == restoreDisk.target:
-                log.info(
-                    "Change target file for disk [%s] from [%s] to [%s]",
-                    restoreDisk.target,
-                    originalFile,
-                    targetFile,
-                )
-                disk.xpath("source")[0].set("file", targetFile)
-
-        return ElementTree.tostring(tree, encoding="utf8", method="xml")
-
     @staticmethod
-    def getBackingStores(disk: _Element) -> List[str]:
+    def getBackingStores(disk: xml._Element) -> List[str]:
         """Get list of backing store files defined for disk, usually
         the case if virtual machine has external snapshots."""
         backingStoreFiles: List[str] = []
@@ -369,7 +284,7 @@ class client:
 
         return backingStoreFiles
 
-    def _getDiskPathByVolume(self, disk: _Element) -> Union[str, None]:
+    def _getDiskPathByVolume(self, disk: xml._Element) -> Union[str, None]:
         """If virtual machine disk is configured via type='volume'
         get path to disk via appropriate libvirt functions,
         pool and volume setting are mandatory as by xml schema definition"""
@@ -462,9 +377,9 @@ class client:
 
     def _createBackupXml(self, args: Namespace, diskList) -> str:
         """Create XML file for starting an backup task using libvirt API."""
-        top = ElementTree.Element("domainbackup", {"mode": "pull"})
+        top = xml.ElementTree.Element("domainbackup", {"mode": "pull"})
         if self.remoteHost == "":
-            ElementTree.SubElement(
+            xml.ElementTree.SubElement(
                 top, "server", {"transport": "unix", "socket": f"{args.socketfile}"}
             )
         else:
@@ -474,16 +389,16 @@ class client:
                 tls = "yes"
             if args.nbd_ip != "":
                 listen = args.nbd_ip
-            ElementTree.SubElement(
+            xml.ElementTree.SubElement(
                 top,
                 "server",
                 {"tls": f"{tls}", "name": f"{listen}", "port": f"{args.nbd_port}"},
             )
 
-        disks = ElementTree.SubElement(top, "disks")
+        disks = xml.ElementTree.SubElement(top, "disks")
 
         if args.cpt.parent != "":
-            inc = ElementTree.SubElement(top, "incremental")
+            inc = xml.ElementTree.SubElement(top, "incremental")
             inc.text = args.cpt.parent
 
         for disk in diskList:
@@ -492,8 +407,8 @@ class client:
             )
             scratchFile = f"{args.scratchdir}/backup.{scratchId}.{disk.target}"
             log.debug("Using scratch file: %s", scratchFile)
-            dE = ElementTree.SubElement(disks, "disk", {"name": disk.target})
-            ElementTree.SubElement(dE, "scratch", {"file": f"{scratchFile}"})
+            dE = xml.ElementTree.SubElement(disks, "disk", {"name": disk.target})
+            xml.ElementTree.SubElement(dE, "scratch", {"file": f"{scratchFile}"})
 
         return xml.indent(top)
 
@@ -501,16 +416,16 @@ class client:
         self, diskList: List[Any], parentCheckpoint: str, checkpointName: str
     ) -> str:
         """Create valid checkpoint XML file which is passed to libvirt API"""
-        top = ElementTree.Element("domaincheckpoint")
-        desc = ElementTree.SubElement(top, "description")
+        top = xml.ElementTree.Element("domaincheckpoint")
+        desc = xml.ElementTree.SubElement(top, "description")
         desc.text = "Backup checkpoint"
-        name = ElementTree.SubElement(top, "name")
+        name = xml.ElementTree.SubElement(top, "name")
         name.text = checkpointName
         if parentCheckpoint != "":
-            pct = ElementTree.SubElement(top, "parent")
-            cptName = ElementTree.SubElement(pct, "name")
+            pct = xml.ElementTree.SubElement(top, "parent")
+            cptName = xml.ElementTree.SubElement(pct, "name")
             cptName.text = parentCheckpoint
-        disks = ElementTree.SubElement(top, "disks")
+        disks = xml.ElementTree.SubElement(top, "disks")
         for disk in diskList:
             # No persistent checkpoint will be created for raw disks,
             # because it is not supported. Backup will only be crash
@@ -523,7 +438,7 @@ class client:
             # See also:
             # https://lists.gnu.org/archive/html/qemu-devel/2021-03/msg07448.html
             if disk.format != "raw":
-                ElementTree.SubElement(disks, "disk", {"name": disk.target})
+                xml.ElementTree.SubElement(disks, "disk", {"name": disk.target})
 
         return xml.indent(top)
 
